# coding: utf-8

"""
    GoodMem API

    API for interacting with the GoodMem service, providing vector-based memory storage and retrieval with multiple embedder support. The service enables creation of memory spaces, storing memories with vector representations, and efficient similarity-based retrieval.

    The version of the OpenAPI document: v1
    Contact: support@goodmem.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class SpaceCreationRequest(BaseModel):
    """
    Request body for creating a new Space. A Space is a container for organizing related memories with vector embeddings.
    """ # noqa: E501
    name: StrictStr = Field(description="The desired name for the space. Must be unique within the user's scope.")
    embedder_id: StrictStr = Field(description="The UUID of an existing Embedder configuration to be used for this space. This determines how memories within this space will be vectorized.", alias="embedderId")
    public_read: Optional[StrictBool] = Field(default=None, description="Indicates if the space and its memories can be read by unauthenticated users or users other than the owner. Defaults to false.", alias="publicRead")
    labels: Optional[Dict[str, StrictStr]] = Field(default=None, description="A set of key-value pairs to categorize or tag the space. Used for filtering and organizational purposes.")
    owner_id: Optional[StrictStr] = Field(default=None, description="Optional owner ID. If not provided, derived from the authentication context. Requires CREATE_SPACE_ANY permission if specified.", alias="ownerId")
    __properties: ClassVar[List[str]] = ["name", "embedderId", "publicRead", "labels", "ownerId"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SpaceCreationRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if public_read (nullable) is None
        # and model_fields_set contains the field
        if self.public_read is None and "public_read" in self.model_fields_set:
            _dict['publicRead'] = None

        # set to None if labels (nullable) is None
        # and model_fields_set contains the field
        if self.labels is None and "labels" in self.model_fields_set:
            _dict['labels'] = None

        # set to None if owner_id (nullable) is None
        # and model_fields_set contains the field
        if self.owner_id is None and "owner_id" in self.model_fields_set:
            _dict['ownerId'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SpaceCreationRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "name": obj.get("name"),
            "embedderId": obj.get("embedderId"),
            "publicRead": obj.get("publicRead"),
            "labels": obj.get("labels"),
            "ownerId": obj.get("ownerId")
        })
        return _obj


